import axios from 'axios'
import { API_URL } from '../constants/ResourceNames'
import { 
    REQUEST_START,
    REQUEST_OK, 
    REQUEST_KO, 
    SHOW_SPINNER, 
    HIDE_SPINNER, 
    SHOW_NOTIFICATION, 
    HIDE_NOTIFICATION 
} from '../constants/ActionTypes'

/**
 * 
 * @param {*} message 
 */
export const spinner = (show, message) => dispatch => {
    dispatch({
        type: show ? SHOW_SPINNER : HIDE_SPINNER,
        payload: message
    })
}

/**
 * 
 * @param {*} text 
 */
export const notify = message => dispatch  => {
    dispatch({
        type: message ? SHOW_NOTIFICATION : HIDE_NOTIFICATION,
        payload: message
    })
}

/**
 * 
 * @param {*} resource 
 */
export const get = resource => async dispatch => {
    dispatch({
        type: REQUEST_START
    })

    try {
        const response = await axios.get(`${API_URL}${resource}`)
        dispatch(ok(response.data))
    } catch (error) {
        dispatch(ko(resource, error))
    }
}

/**
 * 
 * @param {*} resource 
 */
export const post = resources => async dispatch => {
    for (let r of resources) {
        dispatch({
            type: REQUEST_START
        })

        try {
            const response = await axios.post(`${API_URL}${r}`)
            dispatch(ok(response.data))
        } catch (error) {
            dispatch(ko(r, error))
        }
    }
}

/**
 * 
 * @param {*} resource 
 * @param {*} payload 
 */
const ok = payload => {
    return {
        type: REQUEST_OK,
        payload
    }
}

/**
 * 
 * @param {*} resource 
 * @param {*} payload 
 */
const ko = (resource, payload) => {
    return {
        type: REQUEST_KO,
        resource,
        payload
    }
}
